pub struct MonitorBuilder { /* private fields */ }Expand description
Monitors for device events.
A monitor communicates with the kernel over a socket. Filtering events is performed efficiently in the kernel, and only events that match the filters are received by the socket. Filters must be set up before listening for events.
Implementations
Sourceimpl Builder
impl Builder
Sourcepub fn new_kernel() -> Result<Self>
pub fn new_kernel() -> Result<Self>
Creates a new kernel event Monitor.
Sourcepub fn match_subsystem<T: AsRef<OsStr>>(self, subsystem: T) -> Result<Self>
pub fn match_subsystem<T: AsRef<OsStr>>(self, subsystem: T) -> Result<Self>
Adds a filter that matches events for devices with the given subsystem.
Sourcepub fn match_subsystem_devtype<T: AsRef<OsStr>, U: AsRef<OsStr>>(
self,
subsystem: T,
devtype: U,
) -> Result<Self>
pub fn match_subsystem_devtype<T: AsRef<OsStr>, U: AsRef<OsStr>>( self, subsystem: T, devtype: U, ) -> Result<Self>
Adds a filter that matches events for devices with the given subsystem and device type.
Sourcepub fn match_tag<T: AsRef<OsStr>>(self, tag: T) -> Result<Self>
pub fn match_tag<T: AsRef<OsStr>>(self, tag: T) -> Result<Self>
Adds a filter that matches events for devices with the given tag.
Sourcepub fn clear_filters(self) -> Result<Self>
pub fn clear_filters(self) -> Result<Self>
Removes all filters currently set on the monitor.